# -------------------------------------------------------
# 			Micheal de Barra
# Project:	BadMedicine / Amazon - Atkins diets.
# Purpose: 	Dataset and analysis for publication
# Created: 	July 16 2013
#--------------------------------------------------------

library("splines") 
library("survival") 
library("foreign")
library("Hmisc")
library("lsr")
library("stats") 
library("psych") 
library("ggplot2")
library("plyr")
library("sampling")


###############################################
## LOADING DATA  ##############################
###############################################

#set wd
setwd("~/Dropbox/Projects/WhyWeGetSick/Amazon/dataPublication")

# AMAZON DATA: ################################
amazonAtkins <- read.table(file='AmazonWeightsRready.txt', check.names=F, sep='\t', header=T, stringsAsFactors=F)
# OLD HOME: /Users/michealdebarra/Dropbox/Projects/WhyWeGetSick/Amazon/Diets/DataFromAmazon/amazonREVIEWEDexcel/AmazonWeightsRready.txt 


# GARDNER DATA: ################################
# NOTE: Some of these tests (marked !!!Gardner!!) used raw data from Gardner (JAMA, 2007) which I have not make publically available as its not mine.  Please email me if you want this data. 

#!!!!!!! Gardner !!!!!!!
# gardner <- spss.get("GardnerData.por", use.value.labels=TRUE)
# OLD HOME: /Users/michealdebarra/Dropbox/Projects/WhyWeGetSick/Amazon/Diets/DataFromExperiments/GardnerVAmazon/GardnerData.por 

# OTHER DIETS:  ###############################
atda <- read.table("dataDietsDescribed.csv", header=TRUE, sep=";")
# OLD HOME: Users/michealdebarra/Dropbox/Projects/WhyWeGetSick/Amazon/Diets/DataFromExperiments/dataDietsDescribed.csv

head(amazonAtkins)
head(gardner)
head(atda)	 


###############################################
## NEW VARIABLES  #############################
###############################################


# MAKE THE DATES INTO R DATES
amazonAtkins$date <- as.Date(amazonAtkins$DATE, "%B%d%Y")

# CONVERT THE LB TO KG
amazonAtkins$KGchange <- amazonAtkins$Lbchange*0.453592

# CATAGORISE THE DIET DURATIONS (DAYS) INTO "MONTHS". <2 WEEKS AND >15 MONTHS LEFT OUT. SOME LONGER TIME PERIODS LONGER THAN 1 MONTH. 
amazonAtkins$durMon[amazonAtkins$dur >= 15 & amazonAtkins$dur < 45] <- 1
amazonAtkins$durMon[amazonAtkins$dur >= 46 & amazonAtkins$dur < 76] <- 2      
amazonAtkins$durMon[amazonAtkins$dur >= 76 & amazonAtkins$dur < 106] <- 3     
amazonAtkins$durMon[amazonAtkins$dur >= 106 & amazonAtkins$dur < 137] <- 4    
amazonAtkins$durMon[amazonAtkins$dur >= 137 & amazonAtkins$dur < 167] <- 5   
amazonAtkins$durMon[amazonAtkins$dur >= 167 & amazonAtkins$dur < 226] <- 6    
amazonAtkins$durMon[amazonAtkins$dur >= 228 & amazonAtkins$dur < 319] <- 9    
amazonAtkins$durMon[amazonAtkins$dur >= 319 & amazonAtkins$dur < 456] <- 12  



###############################################
## DATA ANALYSIS  #############################
###############################################

# number of atkins reviews
by(data=amazonAtkins, INDICES=amazonAtkins$DIET, FUN=summary)

# number with both duration and kgchange. 
amazonAtkinsSub <- subset(amazonAtkins, dur != "" & KGchange != "")
summary(amazonAtkinsSub)

# descriptive stats for each duration group
by(data=amazonAtkinsSub, INDICES=amazonAtkinsSub$durMon, FUN=summary)
by(data=amazonAtkins, INDICES=amazonAtkins$durMon, FUN=NROW)



# is the distortion similar across a few different time spans?
dateTen <- quantile(amazonAtkinsSub$date, probs = seq(0, 1, 0.1), na.rm = T, names = F, type = 3)

attach(amazonAtkins)
amazonAtkins$dateCat[amazonAtkins$date <= dateTen[2]] <- 1 
amazonAtkins$dateCat[amazonAtkins$date > dateTen[2] & amazonAtkins$date <= dateTen[3]] <- 2 
amazonAtkins$dateCat[amazonAtkins$date > dateTen[3] & amazonAtkins$date <= dateTen[4]] <- 3 
amazonAtkins$dateCat[amazonAtkins$date > dateTen[4] & amazonAtkins$date <= dateTen[5]] <- 4 
amazonAtkins$dateCat[amazonAtkins$date > dateTen[5] & amazonAtkins$date <= dateTen[6]] <- 5 
amazonAtkins$dateCat[amazonAtkins$date > dateTen[6] & amazonAtkins$date <= dateTen[7]] <- 6 
amazonAtkins$dateCat[amazonAtkins$date > dateTen[7] & amazonAtkins$date <= dateTen[8]] <- 7 
amazonAtkins$dateCat[amazonAtkins$date > dateTen[8] & amazonAtkins$date <= dateTen[9]] <- 8 
amazonAtkins$dateCat[amazonAtkins$date > dateTen[9] & amazonAtkins$date <= dateTen[10]] <- 9 
amazonAtkins$dateCat[amazonAtkins$date > dateTen[10]] <- 10 
detach(amazonAtkins)

amazonAtkinsSub <- subset(amazonAtkins, dur != "" & KGchange != "")


# sample size per group
by(data=amazonAtkinsSub, INDICES=amazonAtkinsSub$dateCat, FUN=NROW)

plot(log(amazonAtkins$dur),amazonAtkins$KGchange)
hist(amazonAtkins$date,500)
#### lets work out the predicted weight loss based on the gardner data; assume linear growth between data points. 
# slope = rise / run
slope1 <- (0--4.3)/(0-60)
slope2 <- (-4.3--5.8)/(60-212)
slope3 <- (-5.8--4.55)/(212-365)

# line eqn: y - y1 = m(x - x1)
# expected weight = slope*days + intercept

expKG <- vector()
for (d in 0:60) {
	expKG[d] <- d*slope1 + 0
}

for (d in 61:212) {
	expKG[d] <- d*slope2 - 4.3-(60*slope2)
}

for (d in 213:365) {
	expKG[d] <- d*slope3 - 5.8-(212*slope3)
}
# plot(expKG)
amazonAtkins$expectedKG <- expKG[amazonAtkins$dur]
amazonAtkins$KGdiff <- amazonAtkins$KGchange  - amazonAtkins$expectedKG 


plot(amazonAtkins$dateCat,amazonAtkins$KGdiff)
boxplot(KGchange ~ dateCat,data=amazonAtkins, 	
	ylab = "difference between predicted and actual weight loss",
	xlab = "10 participant groups, 10= most recent")

# (weight change - expected weight) is different from 0 in all ten timepoints 
t.test(amazonAtkins$KGdiff[ which(amazonAtkins$dateCat == 1) ],mu=0)
t.test(amazonAtkins$KGdiff[ which(amazonAtkins$dateCat == 2) ],mu=0)
t.test(amazonAtkins$KGdiff[ which(amazonAtkins$dateCat == 3) ],mu=0)
t.test(amazonAtkins$KGdiff[ which(amazonAtkins$dateCat == 4) ],mu=0)
t.test(amazonAtkins$KGdiff[ which(amazonAtkins$dateCat == 5) ],mu=0)
t.test(amazonAtkins$KGdiff[ which(amazonAtkins$dateCat == 6) ],mu=0)
t.test(amazonAtkins$KGdiff[ which(amazonAtkins$dateCat == 7) ],mu=0)
t.test(amazonAtkins$KGdiff[ which(amazonAtkins$dateCat == 8) ],mu=0)
t.test(amazonAtkins$KGdiff[ which(amazonAtkins$dateCat == 9) ],mu=0)
t.test(amazonAtkins$KGdiff[ which(amazonAtkins$dateCat == 10) ],mu=0)

est <- c(-6.116956,-9.285364 ,-6.169421 ,-7.194832,-7.934321,-6.784313,-7.411284,-7.518316,-6.606046,-10.57117 )
summary(est)
sd(est)

pvals <-  c(6.92e-08, 1.554e-05, 2.319e-09, 5.643e-06, 1.497e-07, 2.595e-07, 3.396e-07, 4.281e-09, 2.868e-08, 4.808e-05)
summary(pvals)
sd(pvals)


# # # some outliers clearly shown in this fig:
# amazonAtkinsSub <- subset(amazonAtkins, dur != "" & KGchange != "")
# amazonAtkinsSub <- subset(amazonAtkinsSub, KGchange > -60 | log(dur) > 6)
# amazonAtkinsWeird <- subset(amazonAtkins, KGchange < -60 & log(dur) < 6)
# # i isolated them checked the raw data. no coding errors on my side. maybe mistake. one is taking the piss (line 143)
        
plot(log(amazonAtkins$dur),amazonAtkins$KGchange)       
plot(log(amazonAtkinsSub$dur),amazonAtkinsSub$KGchange)  
       
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
 
# the problem is, reviews with higher stars tend to have weights and durs. This could confound the result. 
#first, here are the two star distributions. 

amazonAtkins <- amazonAtkins[order(amazonAtkins$star),]
#included reviews             
amazonAtkins$inc <- ifelse(is.na(amazonAtkins$dur) | is.na(amazonAtkins$KGchange), 0 ,1)
#all atkins reviews
amazonAtkinsSub <- subset(amazonAtkins, DIET == "atki")
#all atkins included reviews
amazonAtkinsSubInc <- subset(amazonAtkins,amazonAtkins$inc==1)
par(mfrow=c(2,1))
hist(amazonAtkinsSubInc$star,5)
hist(amazonAtkinsSub$star,5)

# in table
table(amazonAtkinsSub$star)
table(amazonAtkinsSubInc$star)


# so lets look at the ratio in the total sample
table(amazonAtkinsSub$star)/168

# so we would want in the newly selected sample
table(amazonAtkinsSub$star)/168 * 22


# the selection probabilities are therefore
(table(amazonAtkinsSub$star)/168 * 22) / table(amazonAtkinsSubInc$star)

# now, lets add the probabilies to the datframe. 
star1 <- c(rep(1,times=22))
star2 <- c(rep(0.5483631,times=16))
star3 <- c(rep(0.3809524,times=44))
star4 <- c(rep(0.2919397,times=109))
star5 <- c(rep(0.2490079,times=396))
pik=c(star1,star2,star3,star4,star5)

amazonAtkinsSubInc$pik <- pik

# add a random variable
amazonAtkinsSubInc$rand <- runif(587,0,1)

# generate new data set
amazonSubRep <- amazonAtkinsSubInc[ which(amazonAtkinsSubInc$pik > amazonAtkinsSubInc$rand), ]

par(mfrow=c(2,1))
hist(amazonSubRep$star,5)
hist(amazonAtkinsSub$star,5)

par(mfrow=c(2,1))
plot(log(amazonSubRep$dur),amazonSubRep$KGchange)  
plot(log(amazonAtkins$dur),amazonAtkins$KGchange)       


gardnerAt <- subset(gardner, CLASS == "Atkins")

# DIFFERENCE AT TWO MONTHS:
amazonSubRep2 <- amazonSubRep$KGchange[(amazonSubRep$dur >= 46 & amazonSubRep$dur < 77)]
var.test(gardnerAt$WDIFF2MO,amazonSubRep2) 
t.test(gardnerAt$WDIFF2MO,amazonSubRep2)
cohensD(gardnerAt$WDIFF2MO[!is.na(gardnerAt$WDIFF2MO)],amazonSubRep2[!is.na(amazonSubRep2)], method = "unequal")	
NROW(gardnerAt$WDIFF2MO[!is.na(gardnerAt$WDIFF2MO)])
NROW(amazonSubRep2[!is.na(amazonSubRep2)])


# DIFFERENCE AT SIX MONTHS:
(365/12)*4
(365/12)*8
amazonSubRep6 <- amazonSubRep$KGchange[(amazonSubRep$dur >= 121 & amazonSubRep$dur <= 243)]

var.test(gardnerAt$WDIFF6MO,amazonSubRep6) 
t.test(gardnerAt$WDIFF6MO,amazonSubRep6)
cohensD(gardnerAt$WDIFF6MO[!is.na(gardnerAt$WDIFF6MO)],amazonSubRep6[!is.na(amazonSubRep6)], method = "unequal")	
NROW(gardnerAt$WDIFF6MO[!is.na(gardnerAt$WDIFF6MO)])
NROW(amazonSubRep6[!is.na(amazonSubRep6)])


# DIFFERENCE AT 12 MONTHS:
(365/12)*8
(365/12)*16
amazonSubRep12 <- amazonSubRep$KGchange[(amazonSubRep$dur >= 243 & amazonSubRep$dur <= 486)]

var.test(gardnerAt$WDIFF12M,amazonSubRep12) 
t.test(gardnerAt$WDIFF12M,amazonSubRep12)
cohensD(gardnerAt$WDIFF12M[!is.na(gardnerAt$WDIFF12M)],amazonSubRep12[!is.na(amazonSubRep12)], method = "unequal")	
NROW(gardnerAt$WDIFF12M[!is.na(gardnerAt$WDIFF12M)])
NROW(amazonSubRep12[!is.na(amazonSubRep12)])

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
             
                             
#  weight loss is positively correlated with number of stars (rho = .43, p < .001), 
cor.test(amazonAtkins$KGchange,amazonAtkins$star, method = "s")

# duration of diet  (r = .71, p < .001), 
cor.test(amazonAtkins$KGchange,amazonAtkins$dur, method = "s")

# word count (rho = .13, p < .001),  
cor.test(amazonAtkins$KGchange,amazonAtkins$wdCount, method = "s")

# frequency of capitalized letters (r = .04,p = .25)   
cor.test(amazonAtkins$KGchange,amazonAtkins$CAPCount, method = "s")

# or exclamation marks (r = .05, p = .2).   
cor.test(amazonAtkins$KGchange,amazonAtkins$exclamCount, method = "p")


#!!!!!!! Gardner !!!!!!!
# t-tests				  
gardnerAt <- subset(gardner, CLASS == "Atkins")
head(gardnerAt)

# DIFFERENCE AT TWO MONTHS:
amazonAtkins2 <- amazonAtkins$KGchange[(amazonAtkins$dur >= 46 & amazonAtkins$dur < 77)]
var.test(gardnerAt$WDIFF2MO,amazonAtkins2) 
t.test(gardnerAt$WDIFF2MO,amazonAtkins2)
cohensD(gardnerAt$WDIFF2MO[!is.na(gardnerAt$WDIFF2MO)],amazonAtkins2[!is.na(amazonAtkins2)], method = "unequal")	
NROW(gardnerAt$WDIFF2MO[!is.na(gardnerAt$WDIFF2MO)])
NROW(amazonAtkins2[!is.na(amazonAtkins2)])


# DIFFERENCE AT SIX MONTHS:
(365/12)*4
(365/12)*8
amazonAtkins6 <- amazonAtkins$KGchange[(amazonAtkins$dur >= 121 & amazonAtkins$dur <= 243)]

var.test(gardnerAt$WDIFF6MO,amazonAtkins6) 
t.test(gardnerAt$WDIFF6MO,amazonAtkins6)
cohensD(gardnerAt$WDIFF6MO[!is.na(gardnerAt$WDIFF6MO)],amazonAtkins6[!is.na(amazonAtkins6)], method = "unequal")	
NROW(gardnerAt$WDIFF6MO[!is.na(gardnerAt$WDIFF6MO)])
NROW(amazonAtkins6[!is.na(amazonAtkins6)])


# DIFFERENCE AT 12 MONTHS:
(365/12)*8
(365/12)*16
amazonAtkins12 <- amazonAtkins$KGchange[(amazonAtkins$dur >= 243 & amazonAtkins$dur <= 486)]

var.test(gardnerAt$WDIFF12M,amazonAtkins12) 
t.test(gardnerAt$WDIFF12M,amazonAtkins12)
cohensD(gardnerAt$WDIFF12M[!is.na(gardnerAt$WDIFF12M)],amazonAtkins12[!is.na(amazonAtkins12)], method = "unequal")	
NROW(gardnerAt$WDIFF12M[!is.na(gardnerAt$WDIFF12M)])
NROW(amazonAtkins12[!is.na(amazonAtkins12)])
		
		
# proportion that lost 10kg or more at 6 mon. 
amazonAtkins6 <- amazonAtkins$KGchange[(amazonAtkins$dur >= 121 & amazonAtkins$dur <= 243)]
amazonAtkins6ten <- amazonAtkins$KGchange[(amazonAtkins$dur >= 121 & amazonAtkins$dur <= 243 & amazonAtkins$KGchange < -10)]

NROW(amazonAtkins6ten[!is.na(amazonAtkins6ten)]) / NROW(amazonAtkins6[!is.na(amazonAtkins6)])

#!!!!!!! Gardner !!!!!!!
NROW(gardnerAt$WDIFF6MO[gardnerAt$WDIFF6MO < -10 & !is.na(gardnerAt$WDIFF6MO)])/NROW(gardnerAt$WDIFF6MO[!is.na(gardnerAt$WDIFF6MO)])


# reviewer requested test:
# take each person in Gardner and calculate maximum weight loss:
attach(gardner)
gardnerHi <-data.frame(WDIFF2MO, WDIFF6MO, WDIFF12M)
detach(gardner)
gardner$maxLoss <- apply(gardnerHi,1,min, na.rm=T)
subGardner <- subset(gardner, CLASS == "Atkins")
summary(subGardner$maxLoss)
maxLoss <-  subGardner$maxLoss[!is.na(subGardner$maxLoss)]
sd(maxLoss) / sqrt(length(maxLoss))


###############################################
## FIGURE 1: KG LOSS * TIME  ##################
###############################################

noNAam <- !is.na(atda$AMAZON) 

par(mgp = c(2.3, 1, 0),mar=c(3.5, 3.5, 0, 0),cex=.75)


plot(atda$month[noNAam],atda$AMAZON[noNAam],pch=16, col= "1", type="o", lwd=1.2,  
  	xlim=c(0, 12), ylim=c(-30, 0), 
  	ylab="mean change in weight (kg)", 
  	xlab="duration of diet (months)",
  	frame=F
  	)  

noNAga <- !is.na(atda$gardner2007chan_month) 
points(atda$month[noNAga], atda$gardner2007chan[noNAga], pch=16, col="#FF0000FF", type="o", lwd=1.2)

noNAtr <- !is.na(atda$truby2006chan_month) 
points(atda$month[noNAtr], atda$truby2006chan[noNAtr], pch=16, col="#66CD00", type="o", lwd=1.2)

noNAfo <- !is.na(atda$foster2003_month) 
points(atda$month[noNAfo], atda$forster2003all[noNAfo], pch=16, col="#0000FFFF", type="o", lwd=1.2)


legend("bottomleft", inset=.00,
   c(
   #"Shai et al. 2008",
   "Truby et al. 2006", "Gardner et al. 2007",  "Foster et al. 2003","Amazon.com reviews"), 
   col=c(
   #"#FF0000FF",
   "#66CD00","#FF0000FF","#0000FFFF","1"),
   cex = .85, 
   horiz=FALSE, 
   lty=c(1,1,1,1,1),
   lwd=c(1.2, 1.2, 1.2, 1.2, 1.2), 
   bty="n"
   )

###############################################
## FIGURE 2: GARDNER Vs AMAZON ################
###############################################
#!!!!!!! Gardner !!!!!!!

# SUBSETS OF GARDNER 
 
gardner2mon <- subset(x = gardner, subset = CLASS == "Atkins", select = c(WDIFF2MO))	
gardner2months <-  as.matrix(na.omit(gardner2mon)) 

gardner6mon <- subset(x = gardner, subset = CLASS == "Atkins", select = c(WDIFF6MO))
gardner6months <- as.matrix(na.omit(gardner6mon))

gardner12mon <- subset(x = gardner, subset = CLASS == "Atkins", select = c(WDIFF12M))
gardner12months <- as.matrix(na.omit(gardner12mon))

# SUBSETS OF AMAZON
amazon2mo <- subset(x = amazonAtkins, subset = dur >= 46 & dur <= 77, select = c(KGchange))
amazon2months <-  as.matrix(na.omit(amazon2mo)) 

amazon6mo <- subset(x = amazonAtkins, subset = dur >= 121 & dur <= 243, select = c(KGchange))
amazon6months <-  as.matrix(na.omit(amazon6mo)) 

amazon12mo <- subset(x = amazonAtkins, subset = dur >= 243 & dur <= 486, select = c(KGchange))
amazon12months <-  as.matrix(na.omit(amazon12mo)) 

meanAmazon2 <- mean(amazon2months)
meanExp2 <- mean(gardner2months)
meanAmazon6 <- mean(amazon6months)
meanExp6 <- mean(gardner6months)
meanAmazon12 <- mean(amazon12months)
meanExp12 <- mean(gardner12months)

range 		<-  seq(-120, 100, 2)
op <- par(no.readonly = TRUE)
attach(mtcars)
par(mfrow=c(1,3))
# par(mfrow=c(2,3)) this is commented out because Gardner data absent
par(mar = c(2, 2, .8, 1))
# par(mgp = c(1, .1, .1))
par(oma = c(2, 4, .5, 0))
par(cex.main=1.1, font.main = 1)

 nx <- -45
 ny <- 22
 
 hist(gardner2months, xlim = c(-50, 10), ylim = c(0, 25), col=1,
	main=NULL,
	xlab=NULL,
#	xlab = "kg change (n=72)", 
	breaks=range, 
	xaxt='n'	 
	)
text(nx, ny, paste("(n=72)"), pos = 3, cex = 1)
axis(side=1, labels=FALSE)	
abline(v = meanExp2, col = "red")
title(main="2 months") 


hist(gardner6months, xlim = c(-50, 10), ylim = c(0, 25), col=1,
	main=NULL,
	xlab=NULL,
#	xlab = "kg change (n=71)",
	ylab=NULL, 
	breaks=range,
	yaxt='n', 
	xaxt='n'
	)
text(nx, ny, paste("(n=71)"), pos = 3, cex = 1)
axis(side=2, labels=FALSE)
axis(side=1, labels=FALSE)	
abline(v = meanExp6, col = "red") 
title(main="6 months") 
 
hist(gardner12months, xlim = c(-50, 10), ylim = c(0, 25), col=1,
	main=NULL,
	xlab=NULL,
#	xlab = "kg change (n=68)", 				
	ylab=NULL, 
	breaks=range, 
	yaxt='n',
	xaxt='n'
	)
text(nx, ny, paste("(n=69)"), pos = 3, cex = 1)
axis(side=2, labels=FALSE)
axis(side=1, labels=FALSE)	
abline(v = meanExp12, col = "red")
title(main="12 months") 
 
hist(amazon2months, xlim = c(-50, 10),ylim = c(0, 25),col=1, 
	main=NULL,
	xlab = "kg change (1.5 - 2.5 months, n=81)", 
	breaks=range)
text(nx, ny, paste("(n=65)"), pos = 3, cex = 1)
abline(v = meanAmazon2, col = "red")
title(main="2 ± .5  months") 
 
 hist(amazon6months, xlim = c(-50, 10),ylim = c(0, 25),col=1, 
 	main=NULL,
 	xlab = "kg change (5 - 7 months, n=47)", 			
 	ylab=NULL, breaks=range, 
	yaxt='n'
	)
text(nx, ny, paste("(n=68)"), pos = 3, cex = 1)
axis(side=2, labels=FALSE)
abline(v = meanAmazon6, col = "red")
title(main="6 ± 2  months") 
 
 hist(amazon12months, xlim = c(-50, 10),ylim = c(0, 25),col=1, 
 	main=NULL,
 	xlab = "kg change (10 - 14 months, n=42)", 	
 	ylab=NULL, breaks=range, 
	yaxt='n'
	)
text(nx, ny, paste("(n=51)"), pos = 3, cex = 1)
#text(0, 25, paste("12 months"), pos = 3, cex = 1)
axis(side=2, labels=FALSE)
abline(v = meanAmazon12, col = "red")
title(main="12 ± 4  months") 


mtext("weight change (kg)", outer = TRUE,
 side = 1, cex = .8, line = .8)
 
mtext("number of people", outer = TRUE,
 side = 2, cex = .8, line = .9)
 
# mtext("       amazon.com", outer = TRUE,
mtext("amazon.com", outer = TRUE, # use one ABOVE if Gardern present
 side = 2, cex = .9,line = 2.5,col=2) 

# mtext("clinical trial    ", outer = TRUE,
# side = 2, cex = .9,font = 2, line = 2.5, adj = 1, col=1) No Gardner

par(op)



###############################################
## FIGURE MAKER 		  #####################
###############################################

#  FIG1: THE DIETS DESCRIBED.
postscript("dietsDescribed.eps", horizontal = FALSE, onefile = FALSE, paper = "special", height = 3, width = 3.42)

#  FIG2: compare diets.
postscript("compareDiets.eps", horizontal = FALSE, onefile = FALSE, paper = "special", height = 4, width = 6.5)

dev.off()

