# -------------------------------------------------------
# 			Micheal de Barra
# Project:	BadMedicine / Experiments.
# Purpose: 	Dataset and analysis for publication
# Created: 	July 16 2013
#--------------------------------------------------------

library("splines") 
library("survival") 
library("foreign")
library("Hmisc")
library("lsr")
library("stats") 
library("psych") 

###############################################
## LOADING DATA  ##############################
###############################################

setwd("/Users/michealdebarra/Dropbox/Projects/WhyWeGetSick/Amazon/dataPublication")

# EXPERIMENT 1: KG AND STARS DIFFERENT. (6)
experiment1 <- spss.get("exp1data.por", use.value.labels=TRUE)
 
# EXPERIMENT 2: STAR DIFFERENT. (8)
experiment2 <- spss.get("exp2data.por", use.value.labels=TRUE)
 
# EXPERIMENT 3: KG DIFFERENT.  (7)
experiment3 <- spss.get("exp3data.por", use.value.labels=TRUE)

 
###############################################
## DEMOGRAPHICS		 ##########################
###############################################
 

participantSex <- c(experiment1$SEX, experiment3$SEX, experiment2$SEX)
length(participantSex)
summary(participantSex)

participantAge <- c(experiment1$AGE, experiment3$AGE, experiment2$AGE)
length(participantAge)
mean(participantAge,na.rm=TRUE)
sd(participantAge,na.rm=TRUE) 

###############################################
## ANALYSES      ##############################
###############################################

chisq.test(experiment1$DAYATKIN,experiment1$WHICHDIE,correct=FALSE)
chisq.test(experiment2$DAYATKIN,experiment2$WHICHDIE,correct=FALSE)
chisq.test(experiment3$DAYATKIN,experiment3$WHICHDIE,correct=FALSE)


###############################################
## FIGURE        ##############################
###############################################


par(mfrow=c(1,3))

 par(mar = c(1, 1, 1, 1))
# par(mgp = c(1, .1, .1))
 par(oma = c(3, 4, 1, 0))
 par(cex=.5)


# EXPERIMENT 1:  
counts <- table(experiment1$WHICHDIE, experiment1$DAYATKIN)
counts <- c(counts[1,1]-counts[2,1], counts[1,2]-counts[2,2])
counts <- count

barplot(counts, 
  	ylim=c(0, 50),
  	ylab="number of people",  
  	col=c("black","red"),
  	names.arg = c("17-day distorted","Atkins distorted"),
  	beside=TRUE,
  	space=c(0,.5)
  	)
mtext("Experiment 1: Weight and stars altered", outer = F,
 	side = 3,  line = .5, cex=.5
 	) 
  

# EXPERIMENT 2: 
counts <- table(experiment2$WHICHDIE, experiment2$DAYATKIN)
barplot(counts, 
  	axes=FALSE,
  	ylim=c(0, 50),
  	col=c("black","red"),
  	names.arg = c("17-day distorted","Atkins distorted"),
  	beside=TRUE,
  	space=c(0,.5)
  	) 
Axis(side=2, labels=FALSE)
mtext("Experiment 2: Stars altered", outer = F,
 	side = 3,  line = .5, cex=.5
 	) 
  
# EXPERIMENT 3: 
counts <- table(experiment3$WHICHDIE, experiment3$DAYATKIN)
barplot(counts, 
 	axes=FALSE,
  	ylim=c(0, 50),
#  	xlab="condition",
  	col=c("black","red"),
  	names.arg = c("17-day distorted","Atkins distorted"),
  	beside=TRUE,
  	space=c(0,.5)
  	)
Axis(side=2, labels=FALSE)
mtext("Experiment 3: Weight altered", outer = F,
 	side = 3,line = .5, cex=.5
 	) 

legend("topright",                              
	legend=c("Picked Atkins diet", "Picked 17-day diet"),             
  	fill=c("black", "red"),
  	bty="n"
  	)  
  	
  
 mtext("Condition:", outer = TRUE,
 side = 1, line = 0, adj = -.07,cex=.5) 
 
 mtext("number of people", outer = TRUE,
 side = 2, line = 1.6, cex=.5)
 
###############################################
## FIGURE MAKER     ###########################
###############################################

 
# postscript("/Users/michealdebarra/Dropbox/Projects/WhyWeGetSick/Amazon/subProcB/Fig4.eps", horizontal = FALSE, onefile = FALSE, paper = "special", height = 2.5, width = 5)

# dev.off()



###############################################
## Supp FIGURERs  exp 1 KG AND STAR DIFF  #####
###############################################

par(mfrow=c(2,3))

 par(mar = c(1, 1, 1, 1))
# par(mgp = c(1, .1, .1))
 par(oma = c(3, 4, 1, 0))
 par(cex=.6)



experiment1sub <- subset(experiment1, experiment1$AT1 == 1 | 
	experiment1$DAY1 == 1)		# takes all all the one experiments
counts <- table(experiment1sub$WHICHDIE)
barplot(counts, 
 	axes=TRUE,
  	ylim=c(0, 26),
#  	xlab="condition",
  	col=c("black","red"),
  	names.arg = c("Atkins Distorted, Version 1"),
  	beside=TRUE,
  	space=c(0,.5)
  	)

 	
 	
experiment1sub <- subset(experiment1, experiment1$AT2 == 1| 
	experiment1$DAY2 == 1)		# takes all all the TWO experiments
counts <- table(experiment1sub$WHICHDIE)
barplot(counts, 
 	axes=FALSE,
  	ylim=c(0, 26),
#  	xlab="condition",
  	col=c("black","red"),
  	names.arg = c("Atkins Distorted, Version 2"),
  	beside=TRUE,
  	space=c(0,.5)
  	)
Axis(side=2, labels=FALSE)
 
 	

experiment1sub <- subset(experiment1, experiment1$AT3 == 1| 
	experiment1$DAY3 == 1)		# takes all all the TWO experiments
counts <- table(experiment1sub$WHICHDIE)
barplot(counts, 
 	axes=FALSE,
  	ylim=c(0, 26),
#  	xlab="condition",
  	col=c("black","red"),
  	names.arg = c("Atkins Distorted, Version 3"),
  	beside=TRUE,
  	space=c(0,.5)
  	)
Axis(side=2, labels=FALSE)
 	
 	
 	
 	
legend("topright",                              
	legend=c("Picked Atkins diet", "Picked 17-day diet"),             
  	fill=c("black", "red"),
  	bty="y"
  	) 
  	
  	
experiment1sub <- subset(experiment1, as.numeric(as.character(experiment1$AT4)) == 1| 
	experiment1$DAY4 == 1)		# takes all all the FOUR experiments
counts <- table(experiment1sub$WHICHDIE)
barplot(counts, 
 	axes=TRUE,
  	ylim=c(0, 26),
#  	xlab="condition",
  	col=c("black","red"),
  	names.arg = c("17-DAY Distorted, Version 1"),
  	beside=TRUE,
  	space=c(0,.5)
  	)
Axis(side=2, labels=FALSE)
 
 	
experiment1sub <- subset(experiment1, as.numeric(as.character(experiment1$AT5)) == 1| 
	experiment1$DAY5 == 1)		# takes all all the FIVE experiments
counts <- table(experiment1sub$WHICHDIE)
barplot(counts, 
 	axes=FALSE,
  	ylim=c(0, 26),
#  	xlab="condition",
  	col=c("black","red"),
  	names.arg = c("17-DAY Distorted, Version 2"),
  	beside=TRUE,
  	space=c(0,.5)
  	)
Axis(side=2, labels=FALSE)

 	
 	
experiment1sub <- subset(experiment1, experiment1$AT6 == 1| 
	experiment1$DAY6 == 1)		# 
counts <- table(experiment1sub$WHICHDIE)
barplot(counts, 
 	axes=FALSE,
  	ylim=c(0, 26),
#  	xlab="condition",
  	col=c("black","red"),
  	names.arg = c("17-DAY Distorted, Version 3"),
  	beside=TRUE,
  	space=c(0,.5)
  	)
Axis(side=2, labels=FALSE)

 	 
 
 mtext("number of people", outer = TRUE,
 side = 2, line = 1.6, cex=.7)
 
 
 





###############################################
## Supp FIGURERs  exp 2       #######################
###############################################


par(mfrow=c(2,3))

 par(mar = c(1, 1, 1, 1))
# par(mgp = c(1, .1, .1))
 par(oma = c(3, 4, 1, 0))
 par(cex=.6)


experiment2sub <- subset(experiment2, experiment2$AT1 == 1| 
	experiment2$DAY1 == 1)		# takes all all the one experiments
counts <- table(experiment2sub$WHICHDIE)
barplot(counts, 
 	axes=TRUE,
  	ylim=c(0, 26),
#  	xlab="condition",
  	col=c("black","red"),
  	names.arg = c("17-DAY Distorted, Version 1"),
  	beside=TRUE,
  	space=c(0,.5)
  	)

 	
 	
experiment2sub <- subset(experiment2, experiment2$AT2 == 1| 
	experiment2$DAY2 == 1)		# takes all all the TWO experiments
counts <- table(experiment2sub$WHICHDIE)
barplot(counts, 
 	axes=FALSE,
  	ylim=c(0, 26),
#  	xlab="condition",
  	col=c("black","red"),
  	names.arg = c("17-DAY Distorted, Version 2"),
  	beside=TRUE,
  	space=c(0,.5)
  	)
Axis(side=2, labels=FALSE)
 
 	

experiment2sub <- subset(experiment2, experiment2$AT3 == 1| 
	experiment2$DAY3 == 1)		# takes all all the TWO experiments
counts <- table(experiment2sub$WHICHDIE)
barplot(counts, 
 	axes=FALSE,
  	ylim=c(0, 26),
#  	xlab="condition",
  	col=c("black","red"),
  	names.arg = c("17-DAY Distorted, Version 3"),
  	beside=TRUE,
  	space=c(0,.5)
  	)
Axis(side=2, labels=FALSE)
 	
 	
 	
 	
legend("topright",                              
	legend=c("Picked Atkins diet", "Picked 17-day diet"),             
  	fill=c("black", "red"),
  	bty="y"
  	) 
  	
  	
experiment2sub <- subset(experiment2, experiment2$AT4 == 1| 
	experiment2$DAY4 == 1)		# takes all all the FOUR experiments
counts <- table(experiment2sub$WHICHDIE)
barplot(counts, 
 	axes=TRUE,
  	ylim=c(0, 26),
#  	xlab="condition",
  	col=c("black","red"),
  	names.arg = c("Atkins Distorted, Version 1"),
  	beside=TRUE,
  	space=c(0,.5)
  	)
Axis(side=2, labels=FALSE)
 
 	
experiment2sub <- subset(experiment2, experiment2$AT5 == 1| 
	experiment2$DAY5 == 1)		# takes all all the FIVE experiments
counts <- table(experiment2sub$WHICHDIE)
barplot(counts, 
 	axes=FALSE,
  	ylim=c(0, 26),
#  	xlab="condition",
  	col=c("black","red"),
  	names.arg = c("Atkins Distorted, Version 2"),
  	beside=TRUE,
  	space=c(0,.5)
  	)
Axis(side=2, labels=FALSE)

 	
 	
experiment2sub <- subset(experiment2, experiment2$AT6 == 1| 
	experiment2$DAY6 == 1)		# takes all all the FIVE experiments
counts <- table(experiment2sub$WHICHDIE)
barplot(counts, 
 	axes=FALSE,
  	ylim=c(0, 26),
#  	xlab="condition",
  	col=c("black","red"),
  	names.arg = c("Atkins Distorted, Version 3"),
  	beside=TRUE,
  	space=c(0,.5)
  	)
Axis(side=2, labels=FALSE)

 	 
 
 mtext("number of people", outer = TRUE,
 side = 2, line = 1.6, cex=.7)





###############################################
## Supp FIGURERs  exp 3 KG DIFFERENT       #######################
###############################################


par(mfrow=c(2,3))

 par(mar = c(1, 1, 1, 1))
# par(mgp = c(1, .1, .1))
 par(oma = c(3, 4, 1, 0))
 par(cex=.6)

# EXPERIMENT 7: KG AND STARS DIFFERENT. 

experiment3sub <- subset(experiment3, experiment3$ONE == 1)		# takes all all the one experiments
counts <- table(experiment1sub$WHICHDIE)
barplot(counts, 
 	axes=TRUE,
  	ylim=c(0, 26),
#  	xlab="condition",
  	col=c("black","red"),
  	names.arg = c("Atkins Distorted, Version 1"),
  	beside=TRUE,
  	space=c(0,.5)
  	)

 	
 	
experiment3sub <- subset(experiment3, experiment3$TWO == 1)		# takes all all the TWO experiments
counts <- table(experiment3sub$WHICHDIE)
barplot(counts, 
 	axes=FALSE,
  	ylim=c(0, 26),
#  	xlab="condition",
  	col=c("black","red"),
  	names.arg = c("Atkins Distorted, Version 2"),
  	beside=TRUE,
  	space=c(0,.5)
  	)
Axis(side=2, labels=FALSE)
 
 	

experiment3sub <- subset(experiment3, experiment3$THREE == 1)		# takes all all the TWO experiments
counts <- table(experiment3sub$WHICHDIE)
barplot(counts, 
 	axes=FALSE,
  	ylim=c(0, 26),
#  	xlab="condition",
  	col=c("black","red"),
  	names.arg = c("Atkins Distorted, Version 3"),
  	beside=TRUE,
  	space=c(0,.5)
  	)
Axis(side=2, labels=FALSE)
 	
 	
 	
 	
legend("topright",                              
	legend=c("Picked Atkins diet", "Picked 17-day diet"),             
  	fill=c("black", "red"),
  	bty="y"
  	) 
  	
  	
experiment3sub <- subset(experiment3, experiment3$FOUR == 1)		# takes all all the FOUR experiments
counts <- table(experiment3sub$WHICHDIE)
barplot(counts, 
 	axes=TRUE,
  	ylim=c(0, 26),
#  	xlab="condition",
  	col=c("black","red"),
  	names.arg = c("17-DAY Distorted, Version 1"),
  	beside=TRUE,
  	space=c(0,.5)
  	)
Axis(side=2, labels=FALSE)
 
 	
experiment3sub <- subset(experiment3, experiment3$FIVE == 1)		# takes all all the FIVE experiments
counts <- table(experiment3sub$WHICHDIE)
barplot(counts, 
 	axes=FALSE,
  	ylim=c(0, 26),
#  	xlab="condition",
  	col=c("black","red"),
  	names.arg = c("17-DAY Distorted, Version 2"),
  	beside=TRUE,
  	space=c(0,.5)
  	)
Axis(side=2, labels=FALSE)

 	
 	
experiment3sub <- subset(experiment3, experiment3$SIX == 1)		# takes all all the FIVE experiments
counts <- table(experiment3sub$WHICHDIE)
barplot(counts, 
 	axes=FALSE,
  	ylim=c(0, 26),
#  	xlab="condition",
  	col=c("black","red"),
  	names.arg = c("17-DAY Distorted, Version 3"),
  	beside=TRUE,
  	space=c(0,.5)
  	)
Axis(side=2, labels=FALSE)

 	 
 
 mtext("number of people", outer = TRUE,
 side = 2, line = 1.6, cex=.7)
 
 
 
###############################################
## SUPP FIGURE MAKER     ###########################
###############################################

 
postscript("~/Dropbox/Projects/WhyWeGetSick/Amazon/dataPublication/expr3.eps", horizontal = FALSE, onefile = FALSE, paper = "special", height = 5, width = 7)

dev.off()

  
