# -------------------------------------------------------
# 			Micheal de Barra
# Project:	BadMedicine / Amazon - Fertility treatments
# Purpose: 	Dataset and analysis for publication
# Created: 	Aug 13th 2013
#--------------------------------------------------------

###############################################
## LOADING DATA  ##############################
###############################################

fert <- read.csv("FertAllRReady.csv", header=TRUE, sep=",")
head(fert)
#old home: ("Users/michealdebarra/Dropbox/Projects/WhyWeGetSick/AmazonOther/analysis")


###############################################
## NEW VARS  ##################################
###############################################
#dates
rDate <- as.Date(fert$date, "%B %d %Y") 
fert <- data.frame(fert,rDate)

#duration of use
durCycDay <- (as.numeric(as.character(fert$durCyc)))*28
dur <- ifelse(is.na(fert$durDay),durCycDay,fert$durDay)
fert <- data.frame(fert,dur)

#duration of use in cycles length 28 days
durMon <- round(((dur+1)/28),0) #the +1 here makes sure 14 days is included in mon 1 and makes the durMon same as "preg in xth month" calcs below
fert <- data.frame(fert,durMon)

durMon1ex <- ifelse(durMon<1,NA,durMon)
durMon5 <- ifelse(durMon1ex>=5,5,durMon1ex)
fert <- data.frame(fert,durMon5)


## SUBSETTING ##

fert[,2] 			# takes the second column, here stars. 
fert[,"Preg"] 	# here Preg. 
fert$PCOS			# here PCOS

fertsub <- subset(fert, pcos==1)		# takes all the 5 star reviews. 
fertsub <- subset(fert, treat=="fertilAid")	# takes just tea. 
fertsub <- subset(fert, star!=5)	# all but five star reviews. 
fertsub <- subset(fert, star==5 | star==1)	# five or one star reviews
fertsub <- subset(fert, star==3 & PCOS==1)	# five star and PCOS
fertsub <- subset(fert, fert$dur<=14)		# longer than x days.

# aggregate: spits out a data frame.
aggregate(fert$Preg, list(fert$star),mean) # aggrigate by star, then take mean Preg.
aggregate(fert$star, list(fert$dur),mean) # the mean star vlue for preg = 0 and preg = 1. 

# tapply: spits out a matrix.
tapply(fert$star,list(fert$treat),mean)  

# to eliminate the mising values 
is.na(fert$preg)
fertsub <- fert[!is.na(fert$dur),]

###############################################
## DESCRIPTIVES  ##############################
###############################################

# N
nrow(fert)
# number of reviews per diet
summary(fert$treat)

# preg, not preg, and unknown
summary(as.factor(fert$preg))

# duration
NROW(na.omit(fert$dur))
summary(fert$dur)

# of people pregnant, whats median duration to preg? 
fertsub <- subset(fert, fert$preg ==1)	
summary(fertsub$dur)


# proportion pregnant excluding dur < week.
fertsub <- subset(fert, fert$dur>=7)	
table(fertsub$preg)		# subtotal preg and not
# calc 169/(191+169) or preg/(notPreg + preg)
173 / (173+209)


# 153 amazon reviewers who reported a pre-treatment period trying to conceive, 50% reported trying to conceive for a year or more. 
NROW(na.omit(fert$preDur))
median(fert$preDur,na.rm=TRUE)

# fertility problems, number
NROW(na.omit(fert$pcos))
NROW(na.omit(fert$condOth))




###############################################
## ANALYSIS  ##################################
###############################################

# pregancy rates taken from the raw data behind table 1: http://humrep.oxfordjournals.org/content/18/9/1959/F1.large.jpg
# or fulltext here http://humrep.oxfordjournals.org/content/18/9/1959.full

cumProb0 =  0
cumProb1 = 	0.3794
cumProb2 = 	0.5647
cumProb3 =  0.6766 
cumProb4 =  0.7325

N1 = 340
N2 = 340*(1-cumProb1)
N3 = 340*(1-cumProb2)
N4 = 340*(1-cumProb3)

N = c(N1,N2,N3,N4)

# prop preg in mon x = (proportion that becomes preg during x)/(proportion unpreg at begining of x)
preg1 = (cumProb1 - cumProb0) / (1 - cumProb0)
preg2 = (cumProb2 - cumProb1) / (1 - cumProb1)
preg3 = (cumProb3 - cumProb2) / (1 - cumProb2)
preg4 = (cumProb4 - cumProb3) / (1 - cumProb3)

propPreg	<-  	c(preg1,preg2,preg3,preg4)
month 		<- 		c(1:4)

gnoth <- data.frame(month=month,propPreg=propPreg, N=N)
gnoth$preg <- (N*propPreg)
gnoth$notPreg <- (gnoth$N-gnoth$preg)
gnoth
# MONTH 1: AMAZON VERSUS GNOTH  ######################

# pregnant in first cycle. 28 +-14 
fertsub1 <- subset(fert, fert$dur >=14 & fert$dur < 42)	
summary(as.factor(fertsub1$preg))

mon1	<-	matrix(c(100,90,gnoth$preg[1],gnoth$notPreg[1]),ncol=2,byrow=T)
rownames(mon1)<-c("amazon","gnoth")
colnames(mon1)<-c("preg","notpreg")
mon1
prop.test(mon1)

# MONTH 2: AMAZON VERSUS GNOTH  ######################

# pregnant in second cycle. 56 +-14 
fertsub2 <- subset(fert, fert$dur >=42 & fert$dur < 70)	
summary(as.factor(fertsub2$preg))

mon2	<-	matrix(c(35,46,gnoth$preg[2],gnoth$notPreg[2]),ncol=2,byrow=T)
rownames(mon2)<-c("amazon","gnoth")
colnames(mon2)<-c("preg","notpreg")
mon2
prop.test(mon2)

# MONTH 3: AMAZON VERSUS GNOTH  ######################

# pregnant in third cycle. 84 +-14
fertsub3 <- subset(fert, fert$dur >=70 & fert$dur < 98)	
summary(as.factor(fertsub3$preg))

mon3	<-	matrix(c(21,36,gnoth$preg[3],gnoth$notPreg[3]),ncol=2,byrow=T)
rownames(mon3)<-c("amazon","gnoth")
colnames(mon3)<-c("preg","notpreg")
mon3
prop.test(mon3)

###############################################
## GRAPHS    ##################################
###############################################


## three time points    ########################


# 			c(Amaz1,  	 	Gnoth1, 	Am2, 	  	Gn2, 		Am3,		Gn3	)	
par(family = "serif")
		
compare <-  c(0.5263158,	0.3794000, 	0.4320988, 	0.2985820,	0.3684211, 	0.2570641)
dim(compare) <- c(2,3) 
names <- c("cycle 1", "cycle 2", "cycle 3")
par(mar=c(3,3,1,1), cex = .7)

barplot(compare,
	beside=TRUE,
	col=c("red","black"),
	ylim = c(0,.6),
	las = 2,
	yaxt = "n"
#	names.arg = (1:8)
)

# mtext("reproductive cycle (~28 days)", side = 1, line = 2.2, outer = FALSE, at = NA, adj = NA,cex=1.1)
axis(2,at=c(0,.1,.2,.3,.4,.5,.6), label=c("0",".1",".2",".3",".4",".5",".6"), las=2)       
mtext("proportion pregnant", side = 2, line = 2, outer = FALSE, at = NA, adj = NA, cex=.75)  
#mtext("N:", side = 1,adj = .01, line = .2, cex=1)
legend("topright", 
	legend=c("Amazon reviews", "Gnoth et al. 2003"), 
	border = FALSE,
	fill=c("red","black"),
	bty = "n"	
)

points1 <- 	c(0.7, 1.5, 2.5, 4.5, 5.5, 	7.5, 8.5)
ns <- 		c("N:",190, 340, 	81, 211, 		57, 148)
axis(1,at=points1, labels=ns, line, tck=0, pos=0.027, lty=0,cex=.5)  

points2 <- 	c(2, 5, 8)
cyc <- 		c(names)
axis(1,at=points2, labels=cyc, line, tck=0, pos=-.01, lty=0)  


segments(x0=1.5, y0=.57, x1=2.5, y1=.57)
segments(x0=1.5, y0=.57, x1=1.5, y1=.56)
segments(x0=2.5, y0=.57, x1=2.5, y1=.56)
text(x=2, y=.58, labels="**", font=1, ps=8) # add a "significance" label

segments(x0=4.5, y0=.48, x1=5.5, y1=.48)
segments(x0=4.5, y0=.48, x1=4.5, y1=.47)
segments(x0=5.5, y0=.48, x1=5.5, y1=.47)
text(x=5, y=.49, labels="*", font=1, ps=8) # add a "significance" label


# to calculate the sample sizes
mon <-  1
fertsub <- subset(fert, fert$durMon5==mon)
length(fertsub$preg)

# gnoth sample sizes
N 

###############################################
## FIGURE MAKER       #########################
############################################### 

postscript("/Users/michealdebarra/Dropbox/Projects/WhyWeGetSick/Amazon/subProcB/Fig3.eps", horizontal = FALSE, onefile = FALSE, paper = "special", height = 2.5, width = 3.2, par(family = "serif"))


dev.off()

